@@ -4,7 +4,7 @@ use strict;
 package Mail::Message::Head::Delayed;
 use base 'Mail::Reporter';
 
-our $VERSION = 2.00_18;
+our $VERSION = 2.00_19;
 
 use Object::Realize::Later
     becomes          => 'Mail::Message::Head::Complete',
@@ -18,7 +18,7 @@ use Scalar::Util 'weaken';
 
 =head1 NAME
 
-Mail::Message::Head::Delayed - A not-read header of a Mail::Message
+Mail::Message::Head::Delayed - a not-read header of a Mail::Message
 
 =head1 CLASS HIERARCHY
 
@@ -49,10 +49,11 @@ The general methods for C<Mail::Message::Head::Delayed> objects:
   MMH add ...                              new OPTIONS
   MMH build FIELDS                     MMH nrLines
   MMH count NAME                       MMH print FILEHANDLE
-   MR errors                            MR report [LEVEL]
-  MMH get NAME [,INDEX]                 MR reportAll [LEVEL]
-  MMH isDelayed                        MMH reset NAME, FIELDS
-  MMH isMultipart                      MMH set ...
+   MR errors                           MMH printUndisclosed FILEHANDLE
+  MMH get NAME [,INDEX]                 MR report [LEVEL]
+  MMH isDelayed                         MR reportAll [LEVEL]
+  MMH isMultipart                      MMH reset NAME, FIELDS
+  MMH isResent                         MMH set ...
   MMH knownNames                       MMH size
    MR log [LEVEL [,STRINGS]]           MMH timestamp
   MMH modified [BOOL]                  MMH toString
@@ -199,7 +200,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_18.
+This code is beta, version 2.00_19.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
